module type TREE = sig
  type t
  type label
  val children : t -> t list
  val label : t -> label
  val string_of_label : label -> string
end

module type EPS_TREE = sig
  type t
  type label
  val children : t -> t list
  val label : t -> label
  val string_of_label : label -> string

  type color =
    | Gray of float
    | RGB of float * float * float

  type eps_info = {
      rlimit : float ;
      width : float ;
      height : float ;
      foreground : color ;
      background : color ;
      edge_width : float ;
      edge_color : color ;
      label_foreground : color ;
      label_background : color ;
      font_name : string ;
      font_size : float
    }

  type coord = float * float

  val write : string -> eps_info -> t -> coord -> float -> unit
end

module Make(T : TREE) :
    EPS_TREE with type t = T.t and type label = T.label ;;
